@@ -2,23 +2,6 @@
 ### They're centralized here and used in the templates of the ann data
 ### packages instead of being redefined over and over in every templates.
 
-### Used at load time (in .onLoad).
-dbFileConnect <- function(dbfile)
-{
-    ## This is a protection against dbConnect() working even with non-existing
-    ## files (for our use case, the .sqlite file _must_ exist):
-    if (!file.exists(dbfile))
-        stop("DB file '", dbfile, "' not found")
-    dbConnect(SQLite(), dbname=dbfile, cache_size=64000, 
-              synchronous="off", flags=SQLITE_RO)
-}
-
-### Used at unload time (in .onUnload).
-dbFileDisconnect <- function(dbconn)
-{
-    dbDisconnect(dbconn)
-}
-
 ### Used at load time (in .onLoad) by the SQLite-based ann data package to
 ### dynamically add exported symbols to its namespace environment.
 
